Welcome to financepype's documentation!
=====================================

financepype is a Python library for trading on centralized and decentralized exchanges.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   modules/assets
   modules/markets
   modules/operations
   modules/operators
   modules/platforms
   modules/rules
   modules/secrets
   modules/simulations

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
